@@ -3,13 +3,13 @@
 #  Check if dependencies are installed before build.
 #
 #  Note: 
-#  exiftool and ufraw are not needed to build fotoxx,
-#  but they are required at run time to handle EXIF
-#  data and digital camera RAW files.
+#  exiftool and ufraw-batch are not needed to build fotoxx,
+#  but they are required at run time to handle EXIF data 
+#  and RAW files from digital cameras.
 
 dlist=" g++  /usr/include/gtk-2.0/gtk/gtk.h  
         /usr/include/tiffio.h  /usr/lib*/libtiff.so
-        xdg-open  xdg-desktop-menu "
+        xdg-open  xdg-desktop-menu  exiftool"
 
 error=0
 
@@ -21,7 +21,11 @@ do
    fi
    if [ $? -ne 0 ]; then error=1; fi
 done
-if [ $error -eq 0 ]; then exit 0; fi
+
+if [ $error -eq 0 ]
+   then echo "all dependencies found"
+   exit 0
+fi
 
 echo ""
 echo "The following programs and libraries are required"
@@ -31,6 +35,7 @@ echo "g++                  the Gnu C++ compiler and linker"
 echo "libgtk2.0-dev        GTK graphics library (GUI base)"
 echo "libtiff4-dev         TIFF file support library"
 echo "xdg-utils            LSB standard Linux utilities"
+echo "exiftool             EXIF/IPTC image data read and write"
 echo ""
 
 for dname in $dlist
