@@ -1,9 +1,9 @@
 /**************************************************************************
    zfuncs.h      include file for zfuncs functions
 
-   Copyright 2006, 2007, 2008, 2009, 2010  Michael Cornelison
+   Copyright 2006 2007 2008 2009 2010 2011  Michael Cornelison
    source URL:  kornelix.squarespace.com
-   contact: kornelix@yahoo.de
+   contact: kornelix2@googlemail.com
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 ***************************************************************************/
 
-//     zfuncs.h   version  v.3.7
+//     zfuncs.h   version  v.4.3
 
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -66,27 +66,32 @@
 
 //  system functions ======================================================
 
-void appcrash(cchar * pMess, ... );                                        //  fatal exit - works like printf
-void zappcrash(cchar *pMessage, ...);                                      //  crash with popup message in xterm window
+void zappcrash(cchar *pMessage, ...);                                      //  crash with popup message in text window
 void apppause();                                                           //  output message and wait for user
 void apppause(cchar * pMess, ... );                                        //  same, works like printf
 void catch_signals();                                                      //  catch signals and do backtrace dump
+void beroot(int argc = 0, char *argv[] = 0);                               //  restart image as root if password OK
+
 double get_seconds();                                                      //  seconds since 2000.01.01
 void start_timer(double &time0);                                           //  start a timer
 double get_timer(double &time0);                                           //  get elapsed time in seconds
 void start_CPUtimer(double &time0);                                        //  start a process CPU timer
 double get_CPUtimer(double &time0);                                        //  get elapsed CPU time, seconds
 double CPUtime();                                                          //  get elapsed process CPU time used
+void zsleep(double dsecs);                                                 //  sleep specified seconds
+
 void start_detached_thread(void * tfunc(void *), void * arg);              //  start detached thread function
 void synch_threads(int NT = 0);                                            //  synchronize NT threads
+
 int  zget_locked(int &param);                                              //  lock and get multi-thread parameter
 void zput_locked(int &param, int value);                                   //  put and unlock multi-thread parameter
 int  zadd_locked(int &param, int incr);                                    //  increment multi-thread parameter
-void zsleep(double dsecs);                                                 //  sleep specified seconds
+
 char * zmalloc(size_t bytes, cchar *tag = 0);                              //  malloc() with auto crash and log option
 void zfree(void *buff);                                                    //  free() with log option
 void zmalloc_log(int count);                                               //  turn zmalloc() log on/off       v.3.5
 void zmalloc_report();                                                     //  print total memory allocated    v.3.5
+
 char * command_output(int &contx, cchar *command, ...);                    //  get shell command output        v.2.3
 int command_status(int contx);                                             //  get exit status of command
 int signalProc(cchar * pname, cchar * signal);                             //  pause/resume/kill subprocess
@@ -127,6 +132,7 @@ void strnPad(char *dest, cchar *source, int cc);                           //  s
 int  strTrim(char *dest, cchar *source);                                   //  remove trailing blanks
 int  strTrim(char *string);                                                //  remove trailing blanks
 int  strTrim2(char *dest, cchar *source);                                  //  remove leading and trailing blanks
+int  strTrim2(char *string);                                               //  remove leading and trailing blanks
 int  strCompress(char *dest, cchar *source);                               //  remove all blanks incl. imbedded
 int  strCompress(char *string);                                            //  remove all blanks
 int  strncatv(char *dest, int maxcc, cchar *source, ...);                  //  catenate strings (last = 0L) 
@@ -228,14 +234,18 @@ double spline2(double x);                                                  //  r
 #define ZTXmaxent 1000                                                     //  max. translation strings
 #define ZTXmaxcc 2000                                                      //  max. cc per string
 
-int initz_appfiles(cchar *appname, ...);                                   //  find app dirs, copy initial files
+int zinitapp(cchar *appname, ...);                                         //  initz. app directories and files   v.4.1
+cchar * get_zinstalloc();                                                  //  get /usr or /usr/local  ...        v.4.1
 cchar * get_zuserdir();                                                    //  get /home/user/.appname/
-cchar * get_zdatadir();                                                    //  get main install directory
-void showz_userguide(cchar *context = 0);                                  //  show help file in new process
+cchar * get_zdatadir();                                                    //  get install directory
+cchar * get_zdocdir();                                                     //  get document directory             v.3.8
+
+void showz_userguide(cchar *context = 0);                                  //  show user guide in new process
 void showz_readme();                                                       //  show README file in popup window
 void showz_changelog();                                                    //  show changelog file in popup window
 void showz_translations();                                                 //  show TRANSLATIONS file in popup window
-void zmake_launcher(cchar *categories, cchar *genericname);                //  create desktop icon/launcher   v.2.18
+void showz_doctext(cchar *file);                                           //  show text file (or .gz) in a popup window
+void zmake_menu_launcher(cchar *categories, cchar *genericname);           //  add desktop menu and launcher      v.4.1
 
 int ZTXinit(cchar *lang);                                                  //  setup for message translation
 cchar *ZTX(cchar *english);                                                //  get translation for English message
@@ -262,7 +272,7 @@ void wscroll(GtkWidget *mLog, int line);                                   //  s
 void wclear(GtkWidget *Win);                                               //  clear window
 void wclear(GtkWidget *Win, int line);                                     //  clear from line to end
 char * wscanf(GtkWidget *Win, int &ftf);                                   //  get text lines from edit widget
-int wfiledump(GtkWidget *Win, char *filespec);                             //  dump text window to file
+int  wfiledump(GtkWidget *Win, char *filespec);                            //  dump text window to file
 void wfilesave(GtkWidget *Win);                                            //  wfiledump() via file-chooser dialog
 void wprintp(GtkWidget *Win);                                              //  print text window to default printer
 
@@ -337,9 +347,10 @@ int zdialog_run(zdialog *zd, zdialog_event = 0);                           //  r
 int zdialog_send_event(zdialog *zd, cchar *event);                         //  send an event to an active dialog   v.2.17
 int zdialog_send_response(zdialog *zd, int zstat);                         //  complete a dialog, set status   v.2.23
 int zdialog_destroy(zdialog *zd);                                          //  destroy dialog (caller responsibility)
-int zdialog_free(zdialog *zd);                                             //  free zdialog memory
+int zdialog_free(zdialog *&zd);                                            //  free zdialog memory
 int zdialog_wait(zdialog *zd);                                             //  wait for dialog status or be destroyed
 int zdialog_goto(zdialog *zd, cchar *name);                                //  put cursor at named widget  v.2.23
+void zdialog_set_cursor(zdialog *zd, GdkCursor *cursor);                   //  set cursor for dialog window
 
 int zdialog_stuff(zdialog *zd, cchar *name, cchar *data);                  //  stuff string data into widget
 int zdialog_stuff(zdialog *zd, cchar *name, int  data);                    //  stuff int data
@@ -355,30 +366,34 @@ int zdialog_cb_prep(zdialog *zd, cchar *name, cchar *data);                //  p
 char * zdialog_cb_get(zdialog *zd, cchar *name, int Nth);                  //  get combo drop down list Nth entry
 int zdialog_cb_delete(zdialog *zd, cchar *name, cchar *data);              //  delete combo drop down list entry   v.2.4
 int zdialog_cb_clear(zdialog *zd, cchar *name);                            //  clear all combo box entries         v.2.4
+int zdialog_cb_popup(zdialog *zd, cchar *name);                            //  show all combo box list entries     v.3.8
 
 /**************************************************************************/
 
 //   GTK misc. utility functioins
 
-int write_popup_text(cchar *action, cchar *text = 0, int ww = 0, int hh = 0, GtkWidget *parent = 0);  //  write text to popup window
-int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent = 0);                 //  shell command to popup window
+//  write text to popup window, shell command to popup window
+int write_popup_text(cchar *action, cchar *text = 0, int ww = 0, int hh = 0, GtkWidget *parent = 0);
+int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent = 0);
 
-void zmessageACK(GtkWindow *, cchar *pMess, ... );                         //  display message, wait for OK
-void zmessLogACK(GtkWindow *, cchar *pMess, ... );                         //  same, with log to STDOUT
-int zmessageYN(GtkWindow *, cchar *pMess, ... );                           //  display message, wait for YES or NO
-GtkWidget * zmessage_post(GtkWindow *, cchar *pMess, ...);                 //  display message indefinitely   v.2.6
-void zmessage_kill(GtkWidget *dialog);                                     //  kill zmessage_post() message
+void zmessageACK(GtkWidget *parent, cchar *pMess, ... );                   //  display message, wait for OK
+void zmessLogACK(GtkWidget *parent, cchar *pMess, ... );                   //  same, with log to STDOUT
+int zmessageYN(GtkWidget *parent, cchar *pMess, ... );                     //  display message, wait for YES or NO
+void zmessage_help(GtkWidget *parent, cchar *topic, cchar *mess, ...);     //  message box, [help] > user guide topic
+zdialog * zmessage_post(GtkWidget *parent, int secs, cchar *mess, ...);    //  display message until timeout or cancel
+char * zdialog_text(GtkWidget *parent, cchar * title, cchar * initext);    //  get short text input from user
 
-cchar * dialogText(GtkWindow *, cchar * title, cchar * inittext);          //  get short text input from user
-
-char * zgetfile(cchar *title, cchar *file, cchar *rw, cchar *butt = 0);    //  file chooser dialog       v.2.3
-char ** zgetfiles(cchar *title, cchar *file, cchar *butt = 0);             //  multiple file select dialog     v.2.29
+//  file chooser dialogs for 1 file or multiple files
+char  * zgetfile1(cchar *title, cchar *action, cchar *file, cchar *butt = 0);
+char ** zgetfileN(cchar *title, cchar *action, cchar *file, cchar *butt = 0);
 
 void showz_html(cchar *url);                                               //  show html via preferred browser  v.2.18
 
 typedef void drag_drop_func(int x, int y, char *text);                     //  user function, get drag_drop text  v.2.19
 void drag_drop_connect(GtkWidget *window, drag_drop_func);                 //  connect window to user function
 
+GdkCursor * zmakecursor(cchar *iconfile);                                  //  make a cursor from an image file   v.3.7
+
 /**************************************************************************/
 
 //   GDK/GTK image file utility functions
@@ -387,14 +402,16 @@ void drag_drop_connect(GtkWidget *window, drag_drop_func);                 //  c
 void print_imagefile(cchar *file, cchar *format = 0, cchar *orien = 0);    //  print image file (.jpg .png .tif)  v.3.4
 GdkPixbuf * gdk_pixbuf_rotate(GdkPixbuf *, double deg, int alfa = 0);      //  rotate pixbuf through any angle
 
-typedef void image_cbfunc(char *file);                                     //  callback function for clicked thumbnail
-char * image_gallery(cchar *filez, cchar *action, int Nth = 1,             //  display image gallery window, navigate,
-                            image_cbfunc ufunc = 0);                       //    do callback for clicked thumbnails
-int image_position(cchar *file, int *count = 0);                           //  get curr. image position, total image count
+char * image_gallery(cchar *filez, cchar *action, int Nth = 0,             //  display image gallery window, navigate, 
+                      void ufunc(int Nth) = 0, GtkWidget *parent = 0);     //    do callback for clicked thumbnails
+
+int image_gallery_position(cchar *file, int Nth);                          //  get relative position of file in gallery
 int image_file_type(cchar *file);                                          //  determine if directory or image file type
 char * image_thumbfile(cchar *imagefile);                                  //  get thumbnail filespec, create if missing
 GdkPixbuf * image_thumbnail(cchar *imagefile, int size = 0);               //  get thumbnail pixbuf, create if missing
 
+char ** image_gallery_getfiles(char *startdir, GtkWidget *parent = 0);     //  select files from gallery window
+
 /**************************************************************************/
 
 //  parameter management functions
